Enum BinaryError
enum BinaryError
Possible errors returned by the derived implementations of binary arithmetic or logic operations.
Variants
-
Mismatch(WrongVariantError) Operation is attempted between mismatched enum variants.
-
Unit(crate::UnitError) Operation is attempted on unit-like enum variants.
Implementations
impl Clone for BinaryError
fn clone(self: &Self) -> BinaryError
impl Copy for BinaryError
impl Debug for BinaryError
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Display for BinaryError
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Error for BinaryError
fn source(self: &Self) -> Option<&dyn Error + 'static>
impl Freeze for BinaryError
impl RefUnwindSafe for BinaryError
impl Send for BinaryError
impl Sync for BinaryError
impl Unpin for BinaryError
impl UnsafeUnpin for BinaryError
impl UnwindSafe for BinaryError
impl<T> Any for BinaryError
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for BinaryError
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for BinaryError
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for BinaryError
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for BinaryError
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for BinaryError
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T> ToString for BinaryError
fn to_string(self: &Self) -> String
impl<T, U> Into for BinaryError
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for BinaryError
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for BinaryError
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>