Struct TryIntoError

struct TryIntoError<T> { ... }

Error returned by the derived TryInto implementation.

Fields

input: T

Original input value which failed to convert via the derived TryInto implementation.

Implementations

impl<T> Any for TryIntoError<T>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for TryIntoError<T>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for TryIntoError<T>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for TryIntoError<T>

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> Display for TryIntoError<T>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<T> Freeze for TryIntoError<T>

impl<T> From for TryIntoError<T>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> RefUnwindSafe for TryIntoError<T>

impl<T> Send for TryIntoError<T>

impl<T> Sync for TryIntoError<T>

impl<T> ToOwned for TryIntoError<T>

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T> ToString for TryIntoError<T>

fn to_string(self: &Self) -> String

impl<T> Unpin for TryIntoError<T>

impl<T> UnsafeUnpin for TryIntoError<T>

impl<T> UnwindSafe for TryIntoError<T>

impl<T, U> Into for TryIntoError<T>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for TryIntoError<T>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for TryIntoError<T>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>

impl<T: $crate::clone::Clone> Clone for TryIntoError<T>

fn clone(self: &Self) -> TryIntoError<T>

impl<T: $crate::fmt::Debug> Debug for TryIntoError<T>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<T: $crate::marker::Copy> Copy for TryIntoError<T>

impl<T: fmt::Debug> Error for TryIntoError<T>