Struct UnitError
struct UnitError { ... }
Error returned by the derived implementations when an arithmetic or logic operation is invoked on a unit-like variant of an enum.
Implementations
impl Clone for UnitError
fn clone(self: &Self) -> UnitError
impl Copy for UnitError
impl Debug for UnitError
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Display for UnitError
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Error for UnitError
impl Freeze for UnitError
impl RefUnwindSafe for UnitError
impl Send for UnitError
impl Sync for UnitError
impl Unpin for UnitError
impl UnsafeUnpin for UnitError
impl UnwindSafe for UnitError
impl<T> Any for UnitError
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for UnitError
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for UnitError
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for UnitError
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for UnitError
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for UnitError
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T> ToString for UnitError
fn to_string(self: &Self) -> String
impl<T, U> Into for UnitError
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for UnitError
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for UnitError
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>